library silent_auth.src.constants;

class AuthorizeRequest {
  static const scope = "scope";
  static const responseType = "response_type";
  static const clientId = "client_id";
  static const redirectUri = "redirect_uri";
  static const state = "state";
  static const responseMode = "response_mode";
  static const nonce = "nonce";
  static const display = "display";
  static const prompt = "prompt";
  static const maxAge = "max_age";
  static const uiLocales = "ui_locales";
  static const idTokenHint = "id_token_hint";
  static const loginHint = "login_hint";
  static const acrValues = "acr_values";
  static const codeChallenge = "code_challenge";
  static const codeChallengeMethod = "code_challenge_method";
}

class AuthorizeErrors {
// OAuth2 errors
  static const invalidRequest = "invalid_request";
  static const unauthorizedClient = "unauthorized_client";
  static const accessDenied = "access_denied";
  static const unsupportedResponseType = "unsupported_response_type";
  static const invalidScope = "invalid_scope";
  static const serverError = "server_error";
  static const temporarilyUnavailable = "temporarily_unavailable";

// OIDC errors
  static const interactionRequired = "interaction_required";
  static const loginRequired = "login_required";
  static const accountSelectionRequired = "account_selection_required";
  static const consentRequired = "consent_required";
  static const invalidRequestUri = "invalid_request_uri";
  static const invalidRequestObject = "invalid_request_object";
  static const requestNotSupported = "request_not_supported";
  static const requestUriNotSupported = "request_uri_not_supported";
  static const registrationNotSupported = "registration_not_supported";
}

class AuthorizeResponse {
  static const scope = "scope";
  static const code = "code";
  static const accessToken = "access_token";
  static const expiresIn = "expires_in";
  static const tokenType = "token_type";
  static const refreshToken = "refresh_token";
  static const identityToken = "id_token";
  static const state = "state";
  static const error = "error";
  static const errorDescription = "error_description";
}

class EndSessionRequest {
  static const idTokenHint = "id_token_hint";
  static const postLogoutRedirectUri = "post_logout_redirect_uri";
  static const state = "state";
  static const sid = "sid";
  static const issuer = "iss";
}

class TokenRequest {
  static const grantType = "grant_type";
  static const redirectUri = "redirect_uri";
  static const clientId = "client_id";
  static const clientSecret = "client_secret";
  static const clientAssertion = "client_assertion";
  static const clientAssertionType = "client_assertion_type";
  static const assertion = "assertion";
  static const code = "code";
  static const refreshToken = "refresh_token";
  static const scope = "scope";
  static const userName = "username";
  static const password = "password";
  static const codeVerifier = "code_verifier";
  static const tokenType = "token_type";
  static const algorithm = "alg";
  static const key = "key";
}

class TokenRequestTypes {
  static const bearer = "bearer";
  static const pop = "pop";
}

class TokenErrors {
  static const invalidRequest = "invalid_request";
  static const invalidClient = "invalid_client";
  static const invalidGrant = "invalid_grant";
  static const unauthorizedClient = "unauthorized_client";
  static const unsupportedGrantType = "unsupported_grant_type";
  static const unsupportedResponseType = "unsupported_response_type";
  static const invalidScope = "invalid_scope";
}

class TokenResponse {
  static const accessToken = "access_token";
  static const expiresIn = "expires_in";
  static const tokenType = "token_type";
  static const refreshToken = "refresh_token";
  static const identityToken = "id_token";
  static const error = "error";
  static const errorDescription = "error_description";
  static const bearerTokenType = "Bearer";
}

class RegistrationResponse {
  static const error = "error";
  static const errorDescription = "error_description";
  static const clientId = "client_id";
  static const clientSecret = "client_secret";
  static const registrationAccessToken = "registration_access_token";
  static const registrationClientUri = "registration_client_uri";
  static const clientIdIssuedAt = "client_id_issued_at";
  static const clientSecretExpiresAt = "client_secret_expires_at";
}

class TokenTypes {
  static const accessToken = "access_token";
  static const identityToken = "id_token";
  static const refreshToken = "refresh_token";
}

class ResponseTypes {
  static const code = "code";
  static const token = "token";
  static const idToken = "id_token";
  static const idTokenToken = "id_token token";
  static const codeIdToken = "code id_token";
  static const codeToken = "code token";
  static const codeIdTokenToken = "code id_token token";
}

class ResponseModes {
  static const formPost = "form_post";
  static const query = "query";
  static const fragment = "fragment";
}

class PromptModes {
  static const none = "none";
  static const login = "login";
  static const consent = "consent";
  static const selectAccount = "select_account";
}

class CodeChallengeMethods {
  static const plain = "plain";
  static const sha256 = "S256";
}

class ProtectedResourceErrors {
  static const invalidToken = "invalid_token";
  static const expiredToken = "expired_token";
  static const invalidRequest = "invalid_request";
  static const insufficientScope = "insufficient_scope";
}

class EndpointAuthenticationMethods {
  static const postBody = "client_secret_post";
  static const basicAuthentication = "client_secret_basic";
  static const privateKeyJwt = "private_key_jwt";
}

class AuthenticationMethods {
  static const facialRecognition = "face";
  static const fingerprintBiometric = "fpt";
  static const geolocation = "geo";
  static const proofOfPossessionHardwareSecuredKey = "hwk";
  static const irisScanBiometric = "iris";
  static const knowledgeBasedAuthentication = "kba";
  static const multipleChannelAuthentication = "mca";
  static const multiFactorAuthentication = "mfa";
  static const oneTimePassword = "otp";
  static const personalIdentificationOrPattern = "pin";
  static const password = "pwd";
  static const riskBasedAuthentication = "rba";
  static const retinaScanBiometric = "retina";
  static const smartCard = "sc";
  static const confirmationBySms = "sms";
  static const proofOfPossessionSoftwareSecuredKey = "swk";
  static const confirmationByTelephone = "tel";
  static const userPresenceTest = "user";
  static const voiceBiometric = "vbm";
  static const windowsIntegratedAuthentication = "wia";
}

class Algorithms {
  static const none = "none";

// Symmetric

  static const hS256 = "HS256";
  static const hS384 = "HS284";
  static const hS512 = "HS512";

// Asymmetric

  static const rS256 = "RS256";
  static const rS384 = "RS384";
  static const rS512 = "RS512";

  static const eS256 = "ES256";
  static const eS384 = "ES384";
  static const eS512 = "ES512";

  static const pS256 = "PS256";
  static const pS384 = "PS384";
  static const pS512 = "PS512";
}

class Discovery {
  static const issuer = "issuer";

// endpoints
  static const authorizationEndpoint = "authorization_endpoint";
  static const tokenEndpoint = "token_endpoint";
  static const userInfoEndpoint = "userinfo_endpoint";
  static const introspectionEndpoint = "introspection_endpoint";
  static const revocationEndpoint = "revocation_endpoint";
  static const discoveryEndpoint = ".well-known/openid-configuration";
  static const jwksUri = "jwks_uri";
  static const endSessionEndpoint = "end_session_endpoint";
  static const checkSessionIframe = "check_session_iframe";
  static const registrationEndpoint = "registration_endpoint";

// common capabilities
  static const frontChannelLogoutSupported = "frontchannel_logout_supported";
  static const frontChannelLogoutSessionSupported =
      "frontchannel_logout_session_supported";
  static const backChannelLogoutSupported = "backchannel_logout_supported";
  static const backChannelLogoutSessionSupported =
      "backchannel_logout_session_supported";
  static const grantTypesSupported = "grant_types_supported";
  static const codeChallengeMethodsSupported =
      "code_challenge_methods_supported";
  static const scopesSupported = "scopes_supported";
  static const subjectTypesSupported = "subject_types_supported";
  static const responseModesSupported = "response_modes_supported";
  static const responseTypesSupported = "response_types_supported";
  static const claimsSupported = "claims_supported";
  static const tokenEndpointAuthenticationMethodsSupported =
      "token_endpoint_auth_methods_supported";

// more capabilities
  static const claimsLocalesSupported = "claims_locales_supported";
  static const claimsParameterSupported = "claims_parameter_supported";
  static const claimTypesSupported = "claim_types_supported";
  static const displayValuesSupported = "display_values_supported";
  static const acrValuesSupported = "acr_values_supported";
  static const idTokenEncryptionAlgorithmsSupported =
      "id_token_encryption_alg_values_supported";
  static const idTokenEncryptionEncValuesSupported =
      "id_token_encryption_enc_values_supported";
  static const idTokenSigningAlgorithmsSupported =
      "id_token_signing_alg_values_supported";
  static const opPolicyUri = "op_policy_uri";
  static const opTosUri = "op_tos_uri";
  static const requestObjectEncryptionAlgorithmsSupported =
      "request_object_encryption_alg_values_supported";
  static const requestObjectEncryptionEncValuesSupported =
      "request_object_encryption_enc_values_supported";
  static const requestObjectSigningAlgorithmsSupported =
      "request_object_signing_alg_values_supported";
  static const requestParameterSupported = "request_parameter_supported";
  static const requestUriParameterSupported = "request_uri_parameter_supported";
  static const requireRequestUriRegistration =
      "require_request_uri_registration";
  static const serviceDocumentation = "service_documentation";
  static const tokenEndpointAuthSigningAlgorithmsSupported =
      "token_endpoint_auth_signing_alg_values_supported";
  static const uILocalesSupported = "ui_locales_supported";
  static const userInfoEncryptionAlgorithmsSupported =
      "userinfo_encryption_alg_values_supported";
  static const userInfoEncryptionEncValuesSupported =
      "userinfo_encryption_enc_values_supported";
  static const userInfoSigningAlgorithmsSupported =
      "userinfo_signing_alg_values_supported";
}

class Events {
  static const backChannelLogout =
      "http://schemas.openid.net/event/backchannel-logout";
}

class BackChannelLogoutRequest {
  static const logoutToken = "logout_token";
}
